@@ -32,6 +32,7 @@
 #include <Lum/Base/String.h>
 
 #include <Lum/Dlg/About.h>
+#include <Lum/Dlg/ActionDialog.h>
 #include <Lum/Dlg/Progress.h>
 
 #include <Lum/Model/Action.h>
@@ -531,7 +532,7 @@ public:
   }
 };
 
-class MapWindow : public Lum::Dialog
+class MapWindow : public Lum::Dlg::ActionDialog
 {
 private:
   DirEntry *top;
@@ -545,7 +546,7 @@ public:
     Observe(GetClosedAction());
   }
 
-  void PreInit()
+  Lum::Object* GetContent()
   {
     Lum::Panel     *vert;
     Map            *map;
@@ -560,10 +561,13 @@ public:
     vert->Add(map);
     vert->AddSpace();
     vert->Add(Lum::TextValue::Create(map->GetLabel(),true,false));
-    vert->AddSpace();
-    vert->Add(Lum::ButtonRow::CreateClose(GetClosedAction(),true,false));
 
-    SetMain(vert);
+    return vert;
+  }
+
+  void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions)
+  {
+    Lum::Dlg::ActionDialog::CreateActionInfosClose(actions,GetClosedAction());
   }
 
   void Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg)
@@ -572,7 +576,7 @@ public:
       Exit();
     }
 
-    Dialog::Resync(model,msg);
+    Lum::Dlg::ActionDialog::Resync(model,msg);
   }
 };
 
@@ -754,7 +758,6 @@ class MainWindow : public Lum::Dialog
 private:
   Lum::Model::ActionRef              about;
 
-  Lum::Model::ActionRef              showDetail;
   Lum::Model::ActionRef              showMap;
 
   Lum::Model::IntRef                 refreshTime;
@@ -777,7 +780,6 @@ private:
 public:
   MainWindow()
   : about(new Lum::Model::Action()),
-    showDetail(new Lum::Model::Action()),
     showMap(new Lum::Model::Action()),
     refreshTime(new Lum::Model::Int(10)),
     timer(new Lum::Model::Action()),
@@ -797,10 +799,10 @@ public:
     scanTask.SetCaption(L"Scanning directory...");
 
     Observe(about);
-    Observe(showDetail);
     Observe(showMap);
     Observe(refreshTime);
     Observe(timer);
+    Observe(selection);
     Observe(GetOpenedAction());
 
     Observe(scanTask.GetAbortedAction());
@@ -843,7 +845,6 @@ public:
     table->SetModel(tableModel);
     table->SetHeaderModel(headerModel);
     table->SetSelection(selection);
-    table->SetSelectionAction(showDetail);
     table->SetDoubleClickAction(showMap);
     table->SetShowHeader(true);
     table->GetTableView()->SetAutoFitColumns(true);
@@ -1022,7 +1023,7 @@ public:
         Lum::OS::display->AddTimer(refreshTime->Get(),0,timer);
       }
     }
-    else if (model==showDetail && showDetail->IsFinished()) {
+    else if (model==selection) {
       ShowDetail();
     }
     else if (model==showMap && showMap->IsFinished()) {
